ProverBase

Struct ProverBase 

pub struct ProverBase<'a, Zt: ZincTypes<D>, U: Uair, F: PrimeField, const D: usize> { /* private fields */ }
Persistent prover infrastructure carried across every step: the Fiat-Shamir transcript, PCS parameters/hints/commitments, and trace reference.

Implementations

Source

impl<'a, Zt, U, F, const D: usize> ProverBase<'a, Zt, U, F, D>
where Zt: ZincTypes<D>, Zt::Int: ProjectableToField<F>, <Zt::ArbitraryZt as ZipTypes>::Eval: ProjectableToField<F>, U: Uair + 'static, F: InnerTransparentField + FromPrimitiveWithConfig + for<'b> FromWithConfig<&'b Zt::Int> + for<'b> FromWithConfig<&'b Zt::CombR> + for<'b> FromWithConfig<&'b Zt::Chal> + for<'b> MulByScalar<&'b F> + FromRef<F> + Send + Sync + 'static, F::Inner: ConstIntSemiring + ConstTranscribable + FromRef<Zt::Fmod> + Send + Sync + Zero + Default, F::Modulus: ConstTranscribable + FromRef<Zt::Fmod>,

pub fn step1_combined<S: Fn(&U::Scalar, &F::Config) -> DynamicPolynomialF<F>>( self, project_scalar: S, ) -> Result<ProverProjectedCombined<'a, Zt, U, F, D>, ProtocolError<F, U::Ideal>>

Step 1 (combined / row-major): Prime projection (\phi_q: Z[X] -> F_q[X]). Samples a random prime, projects the full trace and scalars using the row-major layout. Works for both linear and non-linear constraints.

pub fn step1_mle_first<S: Fn(&U::Scalar, &F::Config) -> DynamicPolynomialF<F>>( self, project_scalar: S, ) -> Result<ProverProjectedMleFirst<'a, Zt, U, F, D>, ProtocolError<F, U::Ideal>>

Step 1 (MLE-first / column-major): Prime projection (\phi_q: Z[X] -> F_q[X]). Samples a random prime, projects the full trace and scalars using the column-major layout. Only suitable for linear constraints.