ProverPcsOpened

Struct ProverPcsOpened 

pub struct ProverPcsOpened<'a, Zt: ZincTypes<D>, U: Uair, F: PrimeField, const D: usize> { /* private fields */ }
After step 7 (PCS open). No new fields are added here, but the PCS transcript has been updated with the opening proof. Ready for generating the final proof object in finish.

Implementations

Source

impl<'a, Zt, U, F, const D: usize> ProverPcsOpened<'a, Zt, U, F, D>
where Zt: ZincTypes<D>, Zt::Int: ProjectableToField<F>, <Zt::ArbitraryZt as ZipTypes>::Eval: ProjectableToField<F>, U: Uair + 'static, F: InnerTransparentField + FromPrimitiveWithConfig + for<'b> FromWithConfig<&'b Zt::Int> + for<'b> FromWithConfig<&'b Zt::CombR> + for<'b> FromWithConfig<&'b Zt::Chal> + for<'b> MulByScalar<&'b F> + FromRef<F> + Send + Sync + 'static, F::Inner: ConstIntSemiring + ConstTranscribable + FromRef<Zt::Fmod> + Send + Sync + Zero + Default, F::Modulus: ConstTranscribable + FromRef<Zt::Fmod>,

pub fn finish(self) -> Result<Proof<F>, ProtocolError<F, U::Ideal>>

Assemble the final proof from accumulated state.